==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<defaultcodec></defaultcodec>
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>添加檔案</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>清單視圖</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>詳細視圖</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>關閉對話並打開已添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="168"/>
        <source>File name:</source>
        <translation>檔案名：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="184"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="191"/>
        <source>Files of type:</source>
        <translation>檔案類型：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="217"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="107"/>
        <source>Qmmp File Dialog</source>
        <translation>Qmmp 檔案會話</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="106"/>
        <source>About Qmmp File Dialog</source>
        <translation>關於 Qmmp 檔案會話</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="110"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="111"/>
        <source>Some code is copied from the Qt library</source>
        <translation>一些源碼基於 Qt 程式庫</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="215"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="228"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="240"/>
        <source>Directories</source>
        <translation>目錄</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="384"/>
        <source>already exists.</source>
        <translation>早已存在。</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="385"/>
        <source>Do you want to replace it?</source>
        <translation>您想替換它嗎？</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>添加檔案</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>清單視圖</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>詳細視圖</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>關閉對話並打開已添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>檔案名：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>檔案類型：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="121"/>
        <location filename="../qmmpfiledialog.cpp" line="130"/>
        <source>Qmmp File Dialog</source>
        <translation>Qmmp 檔案會話</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="129"/>
        <source>About Qmmp File Dialog</source>
        <translation>關於 Qmmp 檔案會話</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="131"/>
        <source>Writen by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="134"/>
        <source>Some code is copied from the Qt library</source>
        <translation>一些源碼基於 Qt 程式庫</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="272"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="288"/>
        <source>Directories</source>
        <translation>目錄</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="457"/>
        <source>already exists.</source>
        <translation>早已存在。</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="458"/>
        <source>Do you want to replace it?</source>
        <translation>您想替換它嗎？</translation>
    </message>
</context>
</TS>
